==> dubbo-hessian-lite-4.0.4.zip: dubbo-hessian-lite-4.0.4/java-8-test/src/test/java/com/alibaba/com/caucho/hessian/io/ClockTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.com.caucho.hessian.io;


import com.alibaba.com.caucho.hessian.io.base.SerializeTestBase;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledForJreRange;
import org.junit.jupiter.api.condition.JRE;

import java.io.IOException;
import java.time.Clock;
import java.time.ZoneId;

public class ClockTest extends SerializeTestBase {
    @Test
    void test() throws IOException {
        Clock originalClock = Clock.system(ZoneId.of("Asia/Shanghai"));

        Clock result = baseHessian2Serialize(originalClock);

        Assertions.assertEquals(originalClock.getZone(), result.getZone());
    }

    @Test
    @EnabledForJreRange(max = JRE.JAVA_11)
    void testCompact() throws IOException {
        Clock obj = Clock.system(ZoneId.of("Asia/Shanghai"));
        Assertions.assertEquals(obj.getZone(), baseHessian2Serialize(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian3ToHessian3(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian4ToHessian3(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian3ToHessian4(obj).getZone());
    }
}

==> dubbo-hessian-lite-4.0.5.zip: dubbo-hessian-lite-4.0.5/java-8-test/src/test/java/com/alibaba/com/caucho/hessian/io/ClockTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.com.caucho.hessian.io;


import com.alibaba.com.caucho.hessian.io.base.SerializeTestBase;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledForJreRange;
import org.junit.jupiter.api.condition.JRE;

import java.io.IOException;
import java.time.Clock;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.List;

public class ClockTest extends SerializeTestBase {
    @Test
    void test() throws IOException {
        Clock originalClock = Clock.system(ZoneId.of("Asia/Shanghai"));

        Clock result = baseHessian2Serialize(originalClock);

        Assertions.assertEquals(originalClock.getZone(), result.getZone());
    }

    @Test
    @EnabledForJreRange(max = JRE.JAVA_11)
    void testCompact() throws IOException {
        Clock obj = Clock.system(ZoneId.of("Asia/Shanghai"));
        Assertions.assertEquals(obj.getZone(), baseHessian2Serialize(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian3ToHessian3(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian4ToHessian3(obj).getZone());
        Assertions.assertEquals(obj.getZone(), hessian3ToHessian4(obj).getZone());
    }

    @Test
    void testCollection() throws IOException {
        List<Object> list = new ArrayList<>();

        Clock originalClock = Clock.system(ZoneId.of("Asia/Shanghai"));
        testCollection(list, originalClock);
    }
}
